#ifndef __MQCONNU
   #define __MQCONNU 1 /*Indicate that this file has been incl.*/
/*
 * mqconnu.c
 *
 * This is wrapper code for MQCONN and MQCONNX to pass a UserId
 * and Password.
 *
 * @author Roger Lacroix, Capitalware Inc.
 * @version 1.00
 * @license Apache 2 License
 */

/* --------------------------------------------
 * Prototypes
 * --------------------------------------------
 */
void MQCONNU(PMQCHAR, PMQCHAR, PMQCHAR, PMQHCONN, PMQLONG, PMQLONG);
void MQCONNUX(PMQCHAR, PMQCHAR, PMQCHAR, PMQCNO, PMQHCONN, PMQLONG, PMQLONG);

/*
 * Wrapper for MQCONN call that includes a UserId and Password
 */
void MQCONNU(PMQCHAR   pUserId,    /* I: UserId    */
             PMQCHAR   pPassword,  /* I: Password  */
             PMQCHAR   pQMgrName,  /* I: Name of queue manager */
             PMQHCONN  pHconn,     /* O: Connection handle */
             PMQLONG   pCompCode,  /* O: Completion code */
             PMQLONG   pReason)    /* O: Reason code */
{
   /* --------------------------------------------
    * Variable declarations.
    * --------------------------------------------
    */
   MQCNO cno = {MQCNO_DEFAULT};
   MQCSP csp = {MQCSP_DEFAULT};

   /* --------------------------------------------
    * Code section
    * --------------------------------------------
    */
   cno.SecurityParmsPtr = &csp;
   cno.Version = MQCNO_VERSION_5;

   csp.AuthenticationType = MQCSP_AUTH_USER_ID_AND_PWD;

   csp.CSPUserIdPtr = pUserId;
   csp.CSPUserIdOffset = 0;
   csp.CSPUserIdLength = strlen(pUserId);

   csp.CSPPasswordPtr = pPassword;
   csp.CSPPasswordOffset = 0;
   csp.CSPPasswordLength = strlen(pPassword);

   MQCONNX(pQMgrName, &cno, pHconn, pCompCode, pReason);
}

/*
 * Wrapper for MQCONNX call that includes a UserId and Password
 */
void MQCONNUX(PMQCHAR   pUserId,    /* I: UserId    */
              PMQCHAR   pPassword,  /* I: Password  */
              PMQCHAR   pQMgrName,  /* I: Name of queue manager */
              PMQCNO    pCNO,       /* IO: Options that control the action of MQCONNX */
              PMQHCONN  pHconn,     /* O: Connection handle */
              PMQLONG   pCompCode,  /* O: Completion code */
              PMQLONG   pReason)    /* O: Reason code qualifying CompCode */
{
   /* --------------------------------------------
    * Variable declarations.
    * --------------------------------------------
    */
   MQCNO     cno2 = {MQCNO_DEFAULT};
   MQCSP     csp  = {MQCSP_DEFAULT};
   PMQCNO    pCNO2 = &cno2;

   /* --------------------------------------------
    * Code section
    * --------------------------------------------
    */
   if (pCNO != NULL) /* Did the user pass us something? */
      pCNO2 = pCNO;  /* Ok, use it. */

   pCNO2->SecurityParmsPtr = &csp;

   if (pCNO2->Version < MQCNO_VERSION_5)
      pCNO2->Version = MQCNO_VERSION_5;

   csp.AuthenticationType = MQCSP_AUTH_USER_ID_AND_PWD;

   csp.CSPUserIdPtr = pUserId;
   csp.CSPUserIdOffset = 0;
   csp.CSPUserIdLength = strlen(pUserId);

   csp.CSPPasswordPtr = pPassword;
   csp.CSPPasswordOffset = 0;
   csp.CSPPasswordLength = strlen(pPassword);

   MQCONNX(pQMgrName, pCNO2, pHconn, pCompCode, pReason);

   /* clean up because user may have passed us a CNO */
   pCNO2->SecurityParmsPtr = NULL;
}

#endif  /* End of source file */
